# ScriptRunner Connect Managed API for Confluence On-Premise
Managed API for Confluence On-Premise is an API Client for Confluence On-Premise by [Adaptavist](https://www.adaptavist.com/). You can read more about Managed APIs [here](https://docs.adaptavist.com/src/managed-apis).

This is [ScriptRunner Connect](https://scriptrunnerconnect.com) runtime specific version of the Managed API (with `sr-connect` suffix). If you want to use Managed API in any other runtime, have a look at the [runtime agnostic version](https://www.npmjs.com/package/@managed-api/confluence-on-prem-v7-core).

# Supported API calls
- [fetch](https://docs.adaptavist.com/src/managed-apis/managed-api-abstractions)
- Content
    - [createContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-createContent)
    - [getContents](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContent)
    - [updateContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-update)
    - [getContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContentById)
    - [deleteContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-delete)
    - [getContentHistory](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getHistory)
    - Child
        - [getChildren](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-children)
        - [getChildrenOfType](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-childrenOfType)
        - [getComments](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-commentsOfContent)
    - Attachment
        - [getAttachments](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child/attachment-getAttachments)
    - Label
        - [getLabels](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-labels)
        - [addLabels](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-addLabels)
        - [deleteLabel](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-deleteLabel)
    - Watcher
        - [addWatcher](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-addContentWatcher)
        - [removeWatcher](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-removeContentWatcher)
- Space
    - [getSpaces](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-spaces)
    - [createSpace](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-createSpace)
    - [updateSpace](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-update)
    - [deleteSpace](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-delete)
- User
    - [getUser](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user-getUser)

# Constructing Managed API
In ScriptRunner Connect a Managed API is constructed for you, but if you need to construct it manually, here's how you can do it:
```typescript
import { ConfluenceOnPremApi } from '@managed-api/confluence-on-prem-v7-sr-connect';

export default async function() {
    const api = new ConfluenceOnPremApi('API_CONNECTION_ID');
}
```

# Contact
Feel free to drop ideas, suggestions or improvements into our [Slack community channel](https://join.slack.com/t/srconnectcommunity/shared_invite/zt-1c6u4gbyq-KJV_e78H0io7yctNZTBc0A).

# Changelog
- 2.0.0
    - `Breaking change:` URL and query string parameters are now URL encoded, meaning if you encoded them explicitly before you have to remove your own encoding, otherwise they will get double encoded.
- 0.1.2
    - Fixed README

Copyright Adaptavist 2022 (c) All rights reserved